# parts: HC-05

- HC-05/HC-06, Bluetooth module
- https://shop.ideaelec.com/product/hc05-bluetooth-module-with-board/

|   |   |
| --- | --- |
| ![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/HC-05-with-header-board-1.jpg?raw=true) | ![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/HC-05-with-header-board-2.jpg?raw=true) |
